import { cn } from "@/lib/utils";
import { TestCase } from "../../lib/playground";

type PlaygroundTestsProps = {
  tests: TestCase[];
  className?: string;
};

const PlaygroundTests = ({ tests, className }: PlaygroundTestsProps) => {
  return (
    <div className={cn("p-4 flex flex-col gap-2 overflow-y-auto", className)}>
      {tests.map((test) => (
        <div
          key={test.id}
          className={cn(
            "flex flex-row gap-2 justify-between px-4 py-2 rounded-lg bg-base-200",
            test.isFinished && test.expected !== test.result
              ? "bg-error text-error-content"
              : "",
            test.isFinished && test.expected === test.result
              ? "bg-success text-success-content"
              : ""
          )}
        >
          <p>{test.name}</p>
          <p>Expect: {test.expected || "-"}</p>
          <p>
            Result:{" "}
            {typeof test.result === "undefined"
              ? "-"
              : JSON.stringify(test.result)}
          </p>
        </div>
      ))}
    </div>
  );
};

export default PlaygroundTests;
