import { themes } from "@/app/themes";
import { ucfirst } from "@/lib/utils";
import { setTheme, themeStore } from "@/stores/theme.store";
import Button from "@ui/button";
import Dropdown from "@ui/dropdown";
import { Check, Palette } from "lucide-react";
import { ComponentPropsWithoutRef } from "react";
import { useStore } from "zustand";

type ThemeSelectorProps = ComponentPropsWithoutRef<typeof Dropdown>;

const ThemeSelector = (props: ThemeSelectorProps) => {
  const curTheme = useStore(themeStore, (i) => i.theme);

  return (
    <Dropdown trigger={<Button icon={Palette}>Tema</Button>} {...props}>
      {themes.map((theme) => (
        <Dropdown.Item key={theme.name} onClick={() => setTheme(theme.name)}>
          <div className="w-6">
            {curTheme === theme.name && <Check size={16} />}
          </div>
          {ucfirst(theme.name)}
        </Dropdown.Item>
      ))}
    </Dropdown>
  );
};

export default ThemeSelector;
