import { cn } from "@/lib/utils";
import { Slot } from "@radix-ui/react-slot";
import { LucideIcon } from "lucide-react";
import { ComponentPropsWithoutRef, forwardRef } from "react";
import { tv, VariantProps } from "tailwind-variants";

const button = tv({
  base: "btn rounded-xl",
  variants: {
    color: {
      none: "",
      primary: "btn-primary",
      secondary: "btn-secondary",
      neutral: "btn-neutral",
      accent: "btn-accent",
      info: "btn-info",
      success: "btn-success",
      warning: "btn-warning",
      error: "btn-error",
    },
    variant: {
      link: "btn-link",
      outline: "btn-outline",
      ghost: "btn-ghost",
    },
    size: {
      xs: "btn-xs",
      sm: "btn-sm h-10",
      lg: "btn-lg",
      icon: "btn-square",
    },
  },
  defaultVariants: {
    color: "neutral",
  },
});

type ButtonVariants = VariantProps<typeof button>;

type ButtonProps = ComponentPropsWithoutRef<"button"> &
  ButtonVariants & {
    as?: "a" | "button" | "div";
    asChild?: boolean;
    href?: string;
    isLoading?: boolean;
    icon?: LucideIcon;
  };

const Button = forwardRef<HTMLButtonElement, ButtonProps>(
  (
    { as = "button", className, children, isLoading, icon: Icon, ...props },
    ref
  ) => {
    const Comp = props.asChild ? Slot : (as as any);

    return (
      <Comp
        ref={ref}
        role="button"
        className={cn(button(props), className)}
        {...props}
      >
        {isLoading ? (
          <span className="loading loading-spinner"></span>
        ) : Icon ? (
          <Icon />
        ) : null}

        {children}
      </Comp>
    );
  }
);

export default Button;
