import { cn } from "@/lib/utils";
import { Slot } from "@radix-ui/react-slot";
import { LucideIcon } from "lucide-react";
import { useMemo } from "react";
import { tv, VariantProps } from "tailwind-variants";

const dropdown = tv({
  base: "dropdown",
  variants: {
    position: {
      top: "dropdown-top",
      bottom: "dropdown-bottom",
      left: "dropdown-left",
      right: "dropdown-right",
    },
    align: {
      default: "",
      end: "dropdown-end",
    },
  },
  defaultVariants: {
    position: "bottom",
    align: "end",
  },
});

type DropdownProps = VariantProps<typeof dropdown> & {
  tabIndex?: number;
  className?: string;
  contentClassName?: string;
  children?: React.ReactNode;
  trigger?: React.ReactNode;
};

const Dropdown = ({
  tabIndex,
  className,
  contentClassName,
  children,
  trigger,
  ...props
}: DropdownProps) => {
  const tabIdx = useMemo(
    () => tabIndex || Math.round(Math.random() * 10000),
    [tabIndex]
  );

  return (
    <div className={cn(dropdown(props), className)}>
      <Slot tabIndex={tabIdx} role="button" {...({ as: "div" } as any)}>
        {trigger}
      </Slot>
      <ul
        tabIndex={tabIdx}
        className={cn(
          "dropdown-content menu bg-base-200 rounded-box z-[1] w-52 p-2 shadow",
          contentClassName
        )}
      >
        {children}
      </ul>
    </div>
  );
};

type DropdownItemProps = {
  className?: string;
  btnClassName?: string;
  children?: React.ReactNode;
  href?: string;
  onClick?: () => void;
  icon?: LucideIcon;
  title?: string;
};

export const DropdownItem = ({
  className,
  btnClassName,
  children,
  href = "#",
  onClick,
  icon: Icon,
  title,
}: DropdownItemProps) => {
  return (
    <li className={className}>
      <a
        href={href}
        onClick={(e) => {
          if (onClick) {
            e.preventDefault();
            onClick();
          }
        }}
        className={btnClassName}
        title={title}
      >
        {Icon ? <Icon size={16} /> : null}
        {children}
      </a>
    </li>
  );
};

Dropdown.Item = DropdownItem;

export default Dropdown;
