import { themeStore } from "@/stores/theme.store";

export type TestCase = {
  id?: string;
  name: string;
  test: string;
  expected?: any;
  result?: any;
  isFinished?: boolean;
};

type FrameTemplateData = Partial<{
  body: string;
  script: string;
  style: string;
  tests: Pick<TestCase, "id" | "test">[];
}>;

export const frameTemplate = (data: FrameTemplateData) => {
  const colorScheme = themeStore.getState().isDarkMode ? "dark" : "light";

  return `<!DOCTYPE html>
    <html lang="en">
      <head>
        <meta charset="UTF-8">
        <meta name="viewport" content="width=device-width, initial-scale=1.0">
        <meta name="color-scheme" content="${colorScheme}">

        <style>
          html,
          body {
            padding: 0;
            margin: 0;
            font-family: -apple-system, BlinkMacSystemFont, 'Segoe UI', Roboto, Oxygen, Ubuntu, Cantarell, 'Open Sans', 'Helvetica Neue', sans-serif;
          }
          
          * {
            box-sizing: border-box;
          }
          
          pre {
            margin: 0;
            padding: 1rem;
            font-size: 1.2rem;
          }
          
          ${data.style}
        </style>
      </head>
      <body id="body">
        ${data.body}
      </body>

      <script>
        window.consoleFn = {};
        Object.keys(console).forEach(key => { window.consoleFn[key] = function (){}; console[key] = function (...args){ setTimeout(() => window.consoleFn[key](...args), 100); }});
        ${data.script}
      </script>
    </html>`;
};
